a
  color: #000
  &:hover
    color: #f00

p, div
  width: 100em
  & foo
    width: 10em
  &:hover, bar
    height: 20em

#cool
  border:
    style: solid
    width: 2em
  .ie7 &, .ie6 &
    content: string("Totally not cool.")
  .firefox &
    content: string("Quite cool.")

.wow, .snazzy
  font-family: fantasy
  &:hover, &:visited
    font-weight: bold
