

body  
  font: Arial
  background: blue

#page
  width: 700px
  height: 100
  #header
    height: 300px
    h1
      font-size: 50px
      color:     blue

#content.user.show
  #container.top
    #column.left
      width: 100px
    #column.right
      width: 600px
  #container.bottom
    background: brown
