b
  foo: 0.5 * 10px
  bar: 10zzz * 12px / 5zzz
  baz: percentage(12.0px / 18px)
  many-units: 10.0zzz / 3yyy * 12px / 5zzz * 3yyy / 3px * 4em
  mm: 5mm + 1cm
  pc: 1pc + 12pt
  pt: 72pt - 2in
  inches: 1in + 2.54cm
  more-inches: 1in + ((72pt * 2in) + (36pt * 1in)) / 2.54cm
  mixed: (1 + (1em * 6px / 3in)) * 4in / 2em
